==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/place_geo.dart <==
part of keyclic_sdk_api.api;

class PlaceGeo {
  PlaceGeo({
    this.polygon,
    this.elevation,
    this.centroid,
  });

  PlaceGeo.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    polygon = PlaceGeoPolygon.fromJson(json['polygon']);
    elevation = json['elevation']?.toDouble();
    centroid = PlaceGeoCentroid.fromJson(json['centroid']);
  }

  PlaceGeoPolygon polygon;

  double elevation;

  PlaceGeoCentroid centroid;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is PlaceGeo &&
        runtimeType == other.runtimeType &&
        polygon == other.polygon &&
        elevation == other.elevation;
  }

  @override
  int get hashCode => 0 ^ polygon.hashCode ^ elevation.hashCode;

  Map<String, dynamic> toJson() {
    return {
      'polygon': polygon,
      'elevation': elevation,
      'centroid': centroid,
    };
  }

  @override
  String toString() {
    return 'PlaceGeo[polygon=$polygon, elevation=$elevation, centroid=$centroid, ]';
  }

  static List<PlaceGeo> listFromJson(List<dynamic> json) {
    return json == null
        ? List<PlaceGeo>()
        : json.map((value) => PlaceGeo.fromJson(value)).toList();
  }

  static Map<String, PlaceGeo> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, PlaceGeo>();
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = PlaceGeo.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/place_geo.dart <==
part of keyclic_sdk_api.api;

class PlaceGeo {
  PlaceGeo({
    this.centroid,
    this.elevation,
    this.polygon,
  });

  PlaceGeo.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    centroid = PlaceGeoCentroid.fromJson(json['centroid']);
    elevation = json['elevation']?.toDouble();
    polygon = PlaceGeoPolygon.fromJson(json['polygon']);
  }

  PlaceGeoCentroid centroid;

  double elevation;

  PlaceGeoPolygon polygon;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is PlaceGeo &&
        runtimeType == other.runtimeType &&
        centroid == other.centroid &&
        elevation == other.elevation &&
        polygon == other.polygon;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^ centroid.hashCode ^ elevation.hashCode ^ polygon.hashCode;

  static List<PlaceGeo> listFromJson(List<dynamic> json) {
    return json == null
        ? <PlaceGeo>[]
        : json.map((value) => PlaceGeo.fromJson(value)).toList();
  }

  static Map<String, PlaceGeo> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, PlaceGeo>();
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = PlaceGeo.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'centroid': centroid,
      'elevation': elevation,
      'polygon': polygon,
    };
  }

  @override
  String toString() {
    return 'PlaceGeo[centroid=$centroid, elevation=$elevation, polygon=$polygon, ]';
  }
}
